==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/mn.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Сэтгэгдэл",
    "Unknown user" : "  хэрэглэгч",
    "New comment …" : "Шинэ сэтгэгдэл",
    "Delete comment" : "Сэтгэгдэл устгах",
    "Post" : "Нийтлэл",
    "Cancel" : "Цуцлах",
    "Edit comment" : "Сэтгэгдэл засах",
    "[Deleted user]" : "[Хэрэглэгч устгагдсан]",
    "No comments yet, start the conversation!" : "Сэтгэгдэл байхгүй байна",
    "More comments …" : "Дараагийн сэтгэгдэлүүд",
    "Save" : "Хадгалах",
    "Allowed characters {count} of {max}" : "{max} боломжойгоос {count} тэмдэгт орсон байна",
    "Error occurred while retrieving comment with id {id}" : "{id} дугаартай сэтгэгдлийг авахад алдаа гарлаа",
    "Error occurred while updating comment with id {id}" : "{id} дугаартай сэтгэгдлийг шинэчилэхэд алдаа гарлаа",
    "Error occurred while posting comment" : "Сэтгэгдлийг хадгалахад алдаа гарлаа",
    "Comment" : "Сэтгэгдэл",
    "You commented" : "Та сэтгэгдэл бичсэн байна",
    "%1$s commented" : "%1$s сэтгэгдэл бичсэн",
    "{author} commented" : "{author} сэтгэгдэл бичсэн",
    "You commented on %1$s" : "Та %1$s нийтлэл дээр сэтгэгдэл бичсэн байна",
    "You commented on {file}" : "Та {file} сэтгэгдэл бичсэн байна",
    "%1$s commented on %2$s" : "%1$s нь %2$s-д сэтгэгдэл бичсэн",
    "{author} commented on {file}" : "{author} нь {file}-д сэтгэгдэл бичсэн",
    "<strong>Comments</strong> for files" : "Файлууд дахь<strong>Сэтгэгдэлүүд</strong>",
    "A (now) deleted user mentioned you in a comment on “%s”" : "A (now) deleted user mentioned you in a comment on “%s”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s нь таныг “%2$s”-ы сэтгэгдэлд дурдсан",
    "{user} mentioned you in a comment on “{file}”" : "{user} нь таныг “{file}”-ын сэтгэгдэлд дурдсан"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/mn.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Сэтгэгдэл",
    "Unknown user" : "  хэрэглэгч",
    "New comment …" : "Шинэ сэтгэгдэл",
    "Delete comment" : "Сэтгэгдэл устгах",
    "Post" : "Нийтлэл",
    "Cancel" : "Цуцлах",
    "Edit comment" : "Сэтгэгдэл засах",
    "[Deleted user]" : "[Хэрэглэгч устгагдсан]",
    "No comments yet, start the conversation!" : "Сэтгэгдэл байхгүй байна",
    "More comments …" : "Дараагийн сэтгэгдэлүүд",
    "Save" : "Хадгалах",
    "Allowed characters {count} of {max}" : "{max} боломжойгоос {count} тэмдэгт орсон байна",
    "Error occurred while retrieving comment with id {id}" : "{id} дугаартай сэтгэгдлийг авахад алдаа гарлаа",
    "Error occurred while updating comment with id {id}" : "{id} дугаартай сэтгэгдлийг шинэчилэхэд алдаа гарлаа",
    "Error occurred while posting comment" : "Сэтгэгдлийг хадгалахад алдаа гарлаа",
    "Comment" : "Сэтгэгдэл",
    "You commented" : "Та сэтгэгдэл бичсэн байна",
    "%1$s commented" : "%1$s сэтгэгдэл бичсэн",
    "{author} commented" : "{author} сэтгэгдэл бичсэн",
    "You commented on %1$s" : "Та %1$s нийтлэл дээр сэтгэгдэл бичсэн байна",
    "You commented on {file}" : "Та {file} сэтгэгдэл бичсэн байна",
    "%1$s commented on %2$s" : "%1$s нь %2$s-д сэтгэгдэл бичсэн",
    "{author} commented on {file}" : "{author} нь {file}-д сэтгэгдэл бичсэн",
    "<strong>Comments</strong> for files" : "Файлууд дахь<strong>Сэтгэгдэлүүд</strong>",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s нь таныг “%2$s”-ы сэтгэгдэлд дурдсан",
    "{user} mentioned you in a comment on “{file}”" : "{user} нь таныг “{file}”-ын сэтгэгдэлд дурдсан",
    "A (now) deleted user mentioned you in a comment on “%s”" : "A (now) deleted user mentioned you in a comment on “%s”"
},
"nplurals=2; plural=(n != 1);");
